from jd.api.base import RestApi

class CommonImageUploadFileRequest(RestApi):
		def __init__(self,domain,port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.fileContent = None

		def getapiname(self):
			return 'jingdong.common.image.UploadFile'

			







from jd.api.base import RestApi

class ComJdSellerOrderApiCancelFacadeReviewRequest(RestApi):
		def __init__(self,domain,port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.id = None
			self.remark = None
			self.status = None
			self.outWareStatus = None
			self.rejectType = None
			self.language = None

		def getapiname(self):
			return 'jingdong.com.jd.seller.order.api.CancelFacade.review'

			







from jd.api.base import RestApi

class ComEpiPromoOpenApiReadGetPromoListForPageRequest(RestApi):
		def __init__(self,domain,port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.promoId = None
			self.skuId = None
			self.sellerSkuId = None
			self.promoType = None
			self.promoState = None
			self.timeBegin = None
			self.timeEnd = None
			self.pageSize = None
			self.pageIndex = None

		def getapiname(self):
			return 'jingdong.com.epi.promoOpenApiRead.getPromoListForPage'

			




